#
# spec file for package nerdctl
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global provider        github
%global provider_tld    com
%global project         containerd
%global repo            nerdctl
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}

Name:           nerdctl
VCS: https://src.suse.de/ALP-pool/nerdctl#99c54799a54928f536662a384accb49f106c6f73
Version:        1.7.0
Release:        1.4
Summary:        Docker-compatible CLI for containerd
License:        Apache-2.0
URL:            https://github.com/containerd/nerdctl
Source:         %{name}-%{version}.tar.xz
Source1:        vendor.tar.xz
BuildRequires:  golang(API) >= 1.21
Requires:       buildkit
Requires:       cni-plugins
Requires:       containerd
Requires:       iptables
Requires:       rootlesskit >= 1.0.0
Requires:       slirp4netns >= 0.4.0
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
nerdctl is a Docker-compatible CLI for containerd.

%prep
%setup -qa1

%build
CGO_ENABLED=0
go build -mod=vendor -buildmode=pie -o _output/nerdctl %{provider_prefix}/cmd/nerdctl

%install
mkdir -p %{buildroot}%{_bindir}/
install -m 0755 _output/nerdctl %{buildroot}%{_bindir}/nerdctl
install -m 0755 extras/rootless/containerd-rootless-setuptool.sh %{buildroot}%{_bindir}/containerd-rootless-setuptool.sh
install -m 0755 extras/rootless/containerd-rootless.sh %{buildroot}%{_bindir}/containerd-rootless.sh

%files
%license LICENSE
%doc docs/*.md
%{_bindir}/nerdctl
%{_bindir}/containerd-rootless-setuptool.sh
%{_bindir}/containerd-rootless.sh

%changelog
* Mon Dec  4 2023 danish.prakash@suse.com
- Update to version 1.7.0:
  * build(deps): bump github.com/Microsoft/hcsshim from 0.11.2 to 0.11.4
  * update containerd-fuse-overlayfs (1.0.8)
  * Fix unstable sort of container list in compose
  * update imgcrypt (1.1.9)
  * update BuildKit (0.12.3)
  * update runc (1.1.10)
  * update containerd (1.7.8)
  * nerdctl ps: implement `--format {{.Label "foo"}}`
  * Dockerfile: stargz-snapshotter v0.15.1
  * fix add-host overwritten
  * build(deps): bump github.com/containerd/stargz-snapshotter/ipfs
  * build(deps): bump github.com/containerd/imgcrypt from 1.1.8 to 1.1.9
  * build(deps): bump github.com/containerd/stargz-snapshotter
  * nerdctl-full: compile ipfs (Kubo) as a static binary
  * nerdctl-full: compile containerd as static binaries
  * Support IPv6 for nerdctl network
  * Add support to CernVM-FS Snapshotter
  * build(deps): bump github.com/docker/cli
  * support running container with network id
  * build(deps): bump github.com/containerd/containerd from 1.7.7 to 1.7.8
  * build(deps): bump github.com/docker/docker
  * compose_config_test: workaround for Docker Compose v2.23.0
  * Vagrantfile.freebsd: pin generic/freebsd13 to version 4.3.2
  * build(deps): bump google.golang.org/grpc from 1.56.2 to 1.56.3
  * fix ps format names
  * support ip-masq option
  * build(deps): bump github.com/klauspost/compress from 1.17.1 to 1.17.2
  * Replace logrus.SetOutput() with log.L.Logger.SetOutput()
  * docs: minor soci push fix
  * build(deps): bump github.com/containerd/nydus-snapshotter
  * build(deps): bump github.com/containerd/continuity from 0.4.2 to 0.4.3
  * build(deps): bump tonistiigi/xx from 1.2.1 to 1.3.0
  * build(deps): bump github.com/compose-spec/compose-go
  * build(deps): bump github.com/Microsoft/hcsshim from 0.11.1 to 0.11.2
  * build(deps): bump github.com/mattn/go-isatty from 0.0.19 to 0.0.20
  * build(deps): bump actions/checkout from 4.1.0 to 4.1.1
  * build(deps): bump github.com/klauspost/compress from 1.17.0 to 1.17.1
  * Use https://github.com/containerd/log for logging
  * build(deps): bump github.com/containerd/accelerated-container-image
  * fix: typo
  * nerdctl compose: fix --env-file
  * build(deps): bump github.com/containerd/nydus-snapshotter
  * chore: unnecessary code
  * build(deps): bump golang.org/x/net from 0.16.0 to 0.17.0
  * fix: call client close
  * go.mod: github.com/containerd/containerd v1.7.7
  * dockerconfigresolver: nullify DefaultTLS when DefaultScheme == "http"
  * update gotestsum (1.10.0)
  * update Kubo (0.23.0)
  * update containerd-fuse-overlayfs (1.0.7)
  * update slirp4netns (1.2.2)
  * update containerd (1.7.7)
  * containerd/containerd/log -> containerd/log
  * chore: Comment should with an optional leading article
  * build(deps): bump golang.org/x/net from 0.15.0 to 0.16.0
  * release.yml: migrate from `hub` to `gh`
  * build(deps): bump golang.org/x/crypto from 0.13.0 to 0.14.0
  * build(deps): bump golang.org/x/sync from 0.3.0 to 0.4.0
  * build(deps): bump golang.org/x/term from 0.12.0 to 0.13.0
  * build(deps): bump golang.org/x/sys from 0.12.0 to 0.13.0
  * build(deps): bump github.com/containerd/nydus-snapshotter
  * Fix port allocate iptables regex
  * CNI: prioritize `/opt/cni/bin` over `/usr/lib/cni`
  * build(deps): bump github.com/containerd/nydus-snapshotter
  * docs: minor fixes to soci documentation
  * update toml to v2
  * fix: client close connection
  * Support zstd (non-chunked) conversion
  * build(deps): bump github.com/tidwall/gjson from 1.16.0 to 1.17.0
  * build(deps): bump actions/checkout from 4.0.0 to 4.1.0
  * chore: Comment should with an optional leading article
  * build(deps): bump github.com/Microsoft/hcsshim from 0.11.0 to 0.11.1
  * add missing flags for compose ps
  * add featrue network filter
  * build(deps): bump github.com/compose-spec/compose-go
  * image: dedup same platform entry
* Tue Oct 10 2023 danish.prakash@suse.com
- Bump go version to 1.21 (bsc#1215611)
* Wed Sep 27 2023 danish.prakash@suse.com
- Update to version 1.6.0:
  * nerdctl version: skip inspecting rootless daemon if the daemon is not running
  * docs: add SOCI snapshotter guideline in README.md
  * build(deps): bump github.com/klauspost/compress from 1.16.7 to 1.17.0
  * build(deps): bump gotest.tools/v3 from 3.5.0 to 3.5.1
  * update containerd (1.7.6)
  * feat: support push with soci
  * nerdctl compose cp: support rootless
  * compose: silence "build.config should be relative path" warning
  * Implement `nerdctl compose exec -T`
  * docs: fix docs for supported quiet flag of push command
  * build(deps): bump github.com/opencontainers/image-spec
  * add feature nerdctl compose cp
  * build(deps): bump github.com/containerd/nydus-snapshotter
  * seccomp: rename "default" to "builtin" to follow Docker 23
  * update golangci-lint (1.54.2)
  * update soci-snapshotter (0.4.0)
  * update Nydus (2.2.3)
  * update Kubo (0.22.0)
  * update fuse-overlayfs (1.13)
  * update slirp4netns (1.2.1)
  * update RootlessKit (1.1.1)
  * update imgcrypt (1.1.8)
  * update BuildKit (0.12.2)
  * update containerd (1.7.6)
  * build(deps): bump github.com/containerd/containerd from 1.7.5 to 1.7.6
  * build(deps): bump docker/login-action from 2.2.0 to 3.0.0
  * build(deps): bump docker/setup-qemu-action from 2 to 3
  * build(deps): bump docker/metadata-action from 4.6.0 to 5.0.0
  * build(deps): bump docker/setup-buildx-action from 2 to 3
  * build(deps): bump docker/build-push-action from 4.2.1 to 5.0.0
  * build(deps): bump github.com/compose-spec/compose-go
  * remove useless option from containerd-rootless-setuptool
  * build(deps): bump docker/build-push-action from 4.1.1 to 4.2.1
  * MAINTAINERS: add Kay Yan (yankay) as a REVIEWER
  * fix bash completion of volume rm
  * build(deps): bump github.com/cyphar/filepath-securejoin
  * adjust writers fmt
  * fix container_create_windows_test
  * add missing zero-length list check
  * build(deps): bump github.com/docker/cli
  * build(deps): bump github.com/docker/docker
  * build(deps): bump golang.org/x/net from 0.14.0 to 0.15.0
  * build(deps): bump golang.org/x/term from 0.11.0 to 0.12.0
  * build(deps): bump golang.org/x/text from 0.12.0 to 0.13.0
  * build(deps): bump golang.org/x/sys from 0.11.0 to 0.12.0
  * build(deps): bump actions/checkout from 3.6.0 to 4.0.0
  * fix nerdctl run -v when host folder does not exist for bind mounts
  * build(deps): bump github.com/awslabs/soci-snapshotter
  * Makefile: install docs
  * Makefile: fix overriding GO command
  * Makefile: add GO_BUILD_FLAGS variable
  * Makefile: derive BINDIR from PREFIX
  * fix: grammatical errors
  * fix: succeeded typo
  * build(deps): bump github.com/containerd/containerd from 1.7.3 to 1.7.5
  * build(deps): bump actions/checkout from 3.5.3 to 3.6.0
  * Support copying out of volumes in stopped containers
  * Fix typo
  * pkg/version: fulfill fields from `debug/buildinfo`
  * Fix usage of `errors.Join`
  * build(deps): bump github.com/compose-spec/compose-go
  * build(deps): bump github.com/containerd/imgcrypt from 1.1.7 to 1.1.8
  * build(deps): bump golangci/golangci-lint-action from 3.6.0 to 3.7.0
  * support test integration docker 23 compatibility
  * support volume create anonymous
  * update runc (1.1.9)
  * Remove dependency on github.com/hashicorp/go-multierror
  * build(deps): bump github.com/compose-spec/compose-go
  * build(deps): bump github.com/tidwall/gjson from 1.15.0 to 1.16.0
  * Update to Go 1.21 in CI
  * build(deps): bump github.com/fahedouch/go-logrotate from 0.1.3 to 0.2.0
  * FreeBSD: Linux Container Support and BuildKit Integration
  * build(deps): bump golang.org/x/net from 0.13.0 to 0.14.0
  * CI: Windows: enable Hyper-V containers
  * fix attach help is messed up
  * build(deps): bump golang.org/x/crypto from 0.11.0 to 0.12.0
  * CI: move Windows tests to GHA
  * CI: move FreeBSD tests to GHA
  * test-integration-docker-compatibility: install Docker 20.10
  * build(deps): bump github.com/coreos/go-iptables from 0.6.0 to 0.7.0
  * .cirrus.yml: fix FreeBSD CI failure
  * build(deps): bump golang.org/x/net from 0.12.0 to 0.13.0
  * feat: add 'nerdctl container attach'
  * Bump containerd to 1.7.3
  * Remove special case for Windows when mounting view
  * Add lease to prevent containerd GC
* Tue Aug  8 2023 andrea.manzini@suse.com
- Update to version 1.5.0:
  * fix: registry missing layer when concurrently push image
  * update build dependencies
  * feat: add `stats` command to `container`
  * registry documentation update
  * feat: adding support for lazy-pulling with soci in pull and run command
  * Add network flag to nerdctl build
  * Re-enable revive rules
  * Add functionality to copy files into and out of stopped containers.
  * Fix subnet overlapping
  * fix compose lacking support for replicas = 0
  * Fix minor typo in volume flags docs
  * Fix flaky windows test
  * Add metadata to volume create return
  * Remove warning msg when inspect containers without task
  * feat: add --volumes-from support in run command
  * Fix the rule of port allocate when executing -p multiple times for one command
  * Optimize for itoa operations
  * fix the restart policy in kill
  * refactor: container stats command
  * fix update restart policy
  * fix restart policy behaviour inconsistent
  * Prevent timing flakyness for `--since/--until` in TestLogs.
  * docs: fixed typo in command ref for nerdctl logs follow
  * feat: support '--detach-keys' for 'nerdctl (run|start)'
  * User docker compose v2 for docker-comppatible test
  * Adding ability to inject secrets into compose build command
  * Add `shm_size` service option support in Compose files
  * Ignore dependencies for compose build and logs
  * Sort OCI mounts for Docker compliance in nested mount scenario
* Mon May 22 2023 danish.prakash@suse.com
- Update to version 1.4.0:
  * build(deps): bump github.com/docker/cli
  * build(deps): bump github.com/containerd/continuity from 0.4.0 to 0.4.1
  * build(deps): bump github.com/docker/docker
  * nerdctl system prune: skip pruning build cache if buildkit is not running
  * Silence `WARN[0000] failed to get unpacked size of image`
  * build(deps): bump github.com/containerd/continuity from 0.3.0 to 0.4.0
  * build(deps): bump github.com/sirupsen/logrus from 1.9.1 to 1.9.2
  * build(deps): bump github.com/containerd/nydus-snapshotter
  * build(deps): bump github.com/compose-spec/compose-go
  * build(deps): bump github.com/sirupsen/logrus from 1.9.0 to 1.9.1
  * go.mod: containerd/cgroups/v3 v3.0.1, docker/docker v24.0.0
  * nerdctl images: Remove TODOs about VirtualSize
  * build(deps): bump github.com/containerd/accelerated-container-image
  * CI: update containerd (1.7.1)
  * update runc (1.1.7)
  * update fuse-overlayfs (1.12)
  * update containerd-fuse-overlayfs (1.0.6)
  * update gotestsum (1.10.0)
  * update Kubo (0.20.0)
  * update Nydus (2.2.1)
  * update BuildKit (0.11.6)
  * update CNI plugins (1.3.0)
  * update containerd (1.7.1)
  * build(deps): bump github.com/containerd/accelerated-container-image
  * Allow printing of container logs that are not running.
  * build(deps): bump github.com/containerd/containerd from 1.7.0 to 1.7.1
  * build(deps): bump github.com/containernetworking/plugins
  * build(deps): bump github.com/containerd/typeurl/v2 from 2.1.0 to 2.1.1
  * build(deps): bump golang.org/x/crypto from 0.8.0 to 0.9.0
  * go.mod: github.com/opencontainers/image-spec v1.1.0-rc3
  * build(deps): bump github.com/docker/cli
  * build(deps): bump golang.org/x/net from 0.9.0 to 0.10.0
  * build(deps): bump github.com/docker/docker
  * Update Windows tests to use the check HyperV helper
  * build(deps): bump github.com/Microsoft/hcsshim
  * Add Windows tests for the container commands
  * build(deps): bump golang.org/x/term from 0.7.0 to 0.8.0
  * build(deps): bump golang.org/x/sync from 0.1.0 to 0.2.0
  * [Refactor] Refactor the run command in createContainer.
  * Fix: incorrect json format output with `stat` command
  * testutil: Add Hyper-V support check
  * Add Cosign keyless mode required args for nerdctl compose
  * build(deps): bump github.com/docker/cli
  * build(deps): bump github.com/docker/docker
  * vendor: bump nydus-snapshotter v0.8.0
  * convert: enable oci option for nydus conversion type by default
  * Add Cosign keyless mode required args for nerdctl pull and run
  * build(deps): bump github.com/containerd/accelerated-container-image
  * build(deps): bump github.com/compose-spec/compose-go
  * build(deps): bump github.com/docker/cli
  * build(deps): bump github.com/klauspost/compress from 1.16.4 to 1.16.5
  * build(deps): bump docker/metadata-action from 4.3.0 to 4.4.0
  * build(deps): bump github.com/compose-spec/compose-go
  * build(deps): bump github.com/opencontainers/runtime-spec
  * build(deps): bump github.com/docker/docker
  * fix nerdctl exec init console size 0 0 problem
  * add tests
  * build(deps): bump github.com/Microsoft/go-winio from 0.6.0 to 0.6.1
  * add image information to compose ps
  * add json format to compose images
* Thu Apr 20 2023 danish.prakash@suse.com
- Update to version 1.3.1:
  * update kubo (0.19.1)
  * update nydus (2.2.0)
  * go.mod: fix format
  * test: add test for piping of `nerdctl run` with `-t`
  * build(deps): bump actions/checkout from 3.5.1 to 3.5.2
  * cmd/image/list: Fix typo breaking --no-trunc
  * Resolve Go cache warnings in CI workflows
  * Use pushRef instead of ref to build signPef
  * Add destination ports from iptables to used ports while allocating host ports
  * build(deps): bump actions/checkout from 3.5.0 to 3.5.1
  * build(deps): bump github.com/containerd/accelerated-container-image
  * run: make tty output behaviour compatible to docker and `nerdctl exec`
  * build(deps): bump github.com/Masterminds/semver/v3 from 3.2.0 to 3.2.1
  * build(deps): bump golang.org/x/crypto from 0.7.0 to 0.8.0
  * build(deps): bump golang.org/x/net from 0.8.0 to 0.9.0
  * build(deps): bump golang.org/x/text from 0.8.0 to 0.9.0
  * build(deps): bump github.com/klauspost/compress from 1.16.3 to 1.16.4
  * compose: implement Bind.CreateHostPath
* Wed Apr  5 2023 danish.prakash@suse.com
- Update to version 1.3.0:
  * bump: buildkit to v0.11.3, fuse-overlayfs to v1.10, kubo to v0.18.1
  * build(deps): bump golang.org/x/term from 0.6.0 to 0.7.0
  * build(deps): bump github.com/docker/cli
  * build(deps): bump github.com/docker/docker
  * build(deps): bump github.com/spf13/cobra from 1.6.1 to 1.7.0
  * build(deps): bump golang.org/x/sys from 0.6.0 to 0.7.0
  * build(deps): bump github.com/ipfs/go-cid from 0.4.0 to 0.4.1
  * pkg/mountutil: improve error messages
  * use digest instead of a tag while signing
  * Add manugupt1's GPG key
  * build(deps): bump github.com/opencontainers/runc from 1.1.4 to 1.1.5
  * build(deps): bump github.com/docker/docker
  * build(deps): bump github.com/docker/cli
  * build(deps): bump github.com/compose-spec/compose-go
  * Support quiet in push cmd
  * Refactor image sign and verify logic
  * build(deps): bump github.com/compose-spec/compose-go
  * build(deps): bump actions/checkout from 3.4.0 to 3.5.0
  * Fix nerdctl help show the hidden commands
  * set container state error
  * build(deps): bump github.com/mattn/go-isatty from 0.0.17 to 0.0.18
  * rootlessutil: always claim non-rootless on non-Linux.
  * Refactor run command networking options for Windows support.
  * Fix the top command on Windows
  * Add support for showing image size on inspect
  * build(deps): bump github.com/ipfs/go-cid from 0.3.2 to 0.4.0
  * Completely skip syslog-related tests on Windows.
  * test: rootless: main: use v2 config
  * Upgrade cosign to 2.0.0 in tests
  * Add unit test for exposing devices to Windows containers
  * Add MAINTAINERS_GUIDE.md
  * build(deps): bump actions/checkout from 3.3.0 to 3.4.0
  * build(deps): bump github.com/compose-spec/compose-go
  * build(deps): bump actions/setup-go from 3 to 4
  * build(deps): bump github.com/containerd/nydus-snapshotter
  * build(deps): bump github.com/klauspost/compress from 1.16.0 to 1.16.3
  * build(deps): bump github.com/fatih/color from 1.14.1 to 1.15.0
  * update containerd (1.7.0)
  * build(deps): bump github.com/containerd/nydus-snapshotter
  * build(deps): bump github.com/containerd/containerd
  * build(deps): bump github.com/containerd/containerd
  * Drop dependency on ctr/commands
  * Drop dependency on ctr/commands/content
  * Drop dependency on ctr/commands/tasks
  * remote snapshotters: migrate to containerd-based label management
  * build(deps): bump github.com/containerd/containerd
  * Port Windows device support from containerd
  * build(deps): bump golang.org/x/crypto from 0.6.0 to 0.7.0
  * Add notation signing and verification
  * build(deps): bump golang.org/x/net from 0.7.0 to 0.8.0
  * handle container deps removal with postsop hooks
  * build(deps): bump github.com/containerd/containerd
  * Update naming of filter containers function && `container list` handler
  * build(deps): bump github.com/compose-spec/compose-go
  * build(deps): bump github.com/containerd/nydus-snapshotter
  * Fix `operation not permitted` with systemd-homed
  * build(deps): bump github.com/containerd/go-cni
  * build(deps): bump github.com/containerd/nydus-snapshotter
  * feat: resolve special ip host-gateway
  * cmd/compose: add support for profiles
  * refactor(container-list): separate main logic out of printing logic
* Tue Feb 28 2023 danish.prakash@suse.com
- Update to version 1.2.1:
  * update containerd (1.6.19)
  * update Kubo (0.18.1)
  * update Nydus (2.1.4)
  * update BuildKit (0.11.3)
  * build(deps): bump github.com/klauspost/compress from 1.15.15 to 1.16.0
  * build(deps): bump github.com/containerd/containerd
- Add _service file
* Sat Dec 17 2022 contact@marknefedov.dev
- Update to version 1.1.0:
  * nerdctl compose:
  * New commands: nerdctl compose (stop|restart|rm|images|exec|pause|unpause|top|port)
  * New flags: nerdctl compose ps --format=json
  * New YAML properties: x-nerdctl-{verify,cosign-public-key,sign,cosign-private-key}
  * nerdctl image convert:
  * New estargz flags: --estargz-min-chunk-size=<SIZE>, --estargz-external-toc, --estargz-keep-diff-id
  * New zstd flags: --zstdchunked-record-in, --zstdchunked-compression-level, --zstdchunked-chunk-size
  * Support OverlayBD (--overlaybd, --overlaybd-fs-type, --overlaybd-dbstr
  * nerdctl network rm:
  * Support removing a network by ID
  * nerdctl-full:
  * Update containerd (1.6.12), fuse-overlayfs (1.10), RootlessKit (1.1.0), Kubo (0.17.0), Stargz Snapshotter (0.13.0), BuildKit (0.10.6)
* Sat Nov 12 2022 contact@marknefedov.dev
- Update to version 1.0.0:
  * nerdctl run
  * Add --log-driver=syslog
  * Add --log-opt=log-path=<LOGPATH> option for json-file logging drivers
  * Add --mac-address flag
  * Support --pid=container:<CONTAINER>
  * nerdctl build:
  * Support --build-arg args without explicit value
  * Support --output=DIR as an alias of --output type=local,dest=<DIR>
  * nerdctl compose:
  * Add nerdctl compose version command
  * nerdctl-full:
  * Update imgcrypt (1.1.7), BuildKit (0.10.5), stargz-snapshotter (0.12.1), Kubo (0.16.0)
* Fri Apr 22 2022 rpm@fthiessen.de
- Update to version 0.19.0:
  * Add nerdctl cp command
  * nerdctl run:
  * seccomp: relax restrictions depending on --cap-add
  * Add --init flag for enabling tini
  * nerdctl build: Fix content digest ... not found for
    multi-platform images
  * nerdctl push: Add --ipfs-address flag to push to a
    remote IPFS node
  * nerdctl inspect: Add --type=(container|image) flag
  * nerdctl container inspect: Add Mounts field for Docker
    compatibility
  * nerdctl image inspect: Fix the format of Created field
    for Docker compatibility
  * nerdctl volume rm: Refuse removing volumes in use
- Update to version 0.18.0:
  * nerdctl build: Support using containerd worker, for efficiency
    and for supporting local base images
  * nerdctl network create: Switch away from CNI isolation plugin
    to firewall plugin (>= 1.1.0), with ingressPolicy
  * nerdctl run:
  * Support automatic host port assignment for nerdctl run -p
  * Add --ip option
  * nerdctl namespace: Add nerdctl namespace (create|inspect|remove|update) commands
  * nerdctl push: Add --allow-nondistributable-artifacts option
  * Update to use Go 1.18
- Update to version 0.17.1:
  * nerdctl network create:
  * Add --driver=(macvlan|ipvlan)
  * Add --ipam-driver=dhcp
- Update to version 0.17.0:
  * Rootless containers can be now executed without slirp4netns overhead.
  * nerdctl run:
  * Support bypass4netns to bypass slirp4netns overhead:
    nerdctl run --label nerdctl/bypass4netns=true
  * Add nerdctl run --mount
  * nerdctl images: Show blob sizes
  * nerdctl history: Add nerdctl history command
  * Compose: Support multi compose files
  * Kata: Support CNI networking for Kata
- Update to version 0.16.0:
  * Support nerdctl.toml for global configuration
  * nerdctl pull, nerdctl push, nerdctl login:
    Support /etc/containerd/certs.d/<HOST:PORT>/hosts.toml
    (~/.config/containerd/certs.d/<HOST:PORT>/hosts.toml) for configuring certs
  * nerdctl run:
  * Add --verify=cosign and --cosign-key=KEY flags for cosign integration
  * Automatically generate a container name from the image name
  * Add --cpuset-mems, --cpu-quota, and --cpu-period options
  * Add --rdt-class option for Intel RDT classes
  * nerdctl commit:
  * Add --pause=false option
  * Support overriding ENTRYPOINT with --change option
  * nerdctl ipfs registry: Add --read-retry-num and --read-timeout options
  * nerdctl build:
  * Add --label option
  * Add a dummy --rm option
  * nerdctl create: Add nerdctl create command
  * nerdctl network rm: Remove bridge network interface
  * nerdctl compose:
  * Support specifying service name for nerdctl compose pull/push
  * Support labels in nerdctl compose up --build
  * Support specifying subnets
  * Add --services, --volumes, and --hash options for nerdctl compose config
  * Add nerdctl compose kill command
- Update to version 0.15.0:
  * nerdctl pull:
  * Support verifying Cosign signatures: nerdctl pull --verify=cosign
  * Support OverlayBD
  * Add --quiet option (#599, thanks to @Junnplus)
  * nerdctl push: Support signing Cosign signatures: nerdctl push --sign=cosign
  * nerdctl build: Add --iidfile option
  * nerdctl commit: Add --change 'CMD ["foo", "bar"]' option
  * nerdctl load: Support loading gzipped archive
  * nerdctl image convert: Add --zstdchunked option
  * nerdctl exec: Add --user option
  * nerdctl ps: Add --latest and --last options
  * nerdctl stats: Support showing network I/O stats on cgroup v2 hosts
  * nerdctl compose:
  * Add nerdctl compose up --scale option
  * Add nerdctl compose config command
  * Support ulimits
  * Support interpolating host env vars
* Tue Nov 23 2021 rbrown@suse.com
- Initial Packaging
